import scipy_pilutil
import scipy.misc

scipy.misc.pilutil = scipy_pilutil
scipy.misc.__all__ += scipy_pilutil.__all__
for name in scipy_pilutil.__all__:
    setattr(scipy.misc, name, getattr(scipy_pilutil, name))



from .pilutil import *
from . import pilutil

__copyright__    = 'Copyright (C) 2023 kairi'
__version__      = '0.2.1'
__license__      = 'BSD-3-Clause'
__author__       = 'kairi'
__author_email__ = 'kairi.satellite@gmail.com'
__url__          = 'http://github.com/kairi003/scipy_pilutil'

__all__ = pilutil.__all__



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
from codecs import open
from os import path
import re


package_name = 'scipy-pilutil'
module_name = package_name.replace('-', '_')

root_dir = path.abspath(path.dirname(__file__))

def _requires_from_file(filename):
    return open(filename).read().splitlines()

with open(path.join(root_dir, module_name, '__init__.py')) as f:
    init_text = f.read()
    version = re.search(r'__version__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
    license = re.search(r'__license__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
    author = re.search(r'__author__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
    author_email = re.search(r'__author_email__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
    url = re.search(r'__url__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)

assert version
assert license
assert author
assert author_email
assert url

setup(
    name=package_name,
    version=version,
    license=license,
    description="scipy.misc.pilutil module for legacy code",
    author=author,
    author_email=author_email,
    url=url,
    packages=find_packages(),
    install_requires=_requires_from_file('requirements.txt')
)
